@@ -11,7 +11,7 @@ import string
 from io import StringIO
 
 import pytest
-from hypothesis import given, settings, HealthCheck, assume, example
+from hypothesis import given, settings, HealthCheck, assume
 import hypothesis.strategies as st
 
 import srt
@@ -241,12 +241,6 @@ def test_subtitle_inequality(sub_1):
     assert sub_1 != sub_2
 
 
-@given(subtitles())
-def test_subtitle_inequality_to_non_matching_type(sub_1):
-    assert sub_1 != None
-    assert sub_1 != 1
-
-
 @given(subtitles())
 def test_subtitle_from_scratch_equality(subtitle):
     srt_block = subtitle.to_srt()
@@ -362,11 +356,10 @@ def test_subs_starts_before_zero_removed(positive_subs, negative_subs, negative_
 @given(st.lists(subtitles(), min_size=1), st.integers(min_value=0))
 def test_sort_and_reindex(input_subs, start_index):
     for sub in input_subs:
-        # Pin all subs to same end time and index so that start time is
-        # compared only, must be guaranteed to be < sub.start, see how
+        # Pin all subs to same end time so that start time is compared only,
+        # must be guaranteed to be < sub.start, see how
         # start_timestamp_strategy is done
         sub.end = timedelta(500001)
-        sub.index = 1
 
     reindexed_subs = list(
         srt.sort_and_reindex(input_subs, start_index=start_index, in_place=True)
@@ -396,28 +389,11 @@ def test_sort_and_reindex_no_skip(input_subs):
     assert len(reindexed_subs) == len(input_subs)
 
 
-@given(st.lists(subtitles()))
-def test_sort_and_reindex_handles_no_index(input_subs):
-    # end time > start time should not trigger a skip if skip=False
-    for sub in input_subs:
-        old_start = sub.start
-        sub.start = sub.end
-        sub.end = old_start
-        sub.index = None
-
-    reindexed_subs = list(srt.sort_and_reindex(input_subs))
-
-    # Everything should have been skipped
-    assert not reindexed_subs
-
-
 @given(st.lists(subtitles(), min_size=1))
 def test_sort_and_reindex_same_start_time_uses_end(input_subs):
     for sub in input_subs:
-        # Pin all subs to same start time and index so that end time is
-        # compared only
+        # Pin all subs to same start time so that end time is compared only
         sub.start = timedelta(1)
-        sub.index = 1
 
     reindexed_subs = list(srt.sort_and_reindex(input_subs, in_place=True))
 
@@ -426,22 +402,6 @@ def test_sort_and_reindex_same_start_time_uses_end(input_subs):
     assert reindexed_subs == expected_sorting
 
 
-@given(st.lists(subtitles(), min_size=1))
-def test_sort_and_reindex_same_start_and_end_time_uses_index(input_subs):
-    for sub in input_subs:
-        # Pin all subs to same start and end time so that index is compared
-        # only
-        sub.start = timedelta(1)
-        sub.end = timedelta(2)
-
-    reindexed_subs = list(srt.sort_and_reindex(input_subs, in_place=True))
-
-    # The subtitles should be sorted by index when start and end time are the
-    # same
-    expected_sorting = sorted(input_subs, key=lambda sub: sub.index)
-    assert reindexed_subs == expected_sorting
-
-
 @given(st.lists(subtitles(), min_size=1), st.integers(min_value=0))
 def test_sort_and_reindex_not_in_place_matches(input_subs, start_index):
     # Make copies for both sort_and_reindex calls so that they can't affect
@@ -726,48 +686,3 @@ def test_can_parse_index_leading_zeroes(input_subs, zeroes):
 
     reparsed_subs = srt.parse(out)
     subs_eq(reparsed_subs, input_subs)
-
-
-@given(st.lists(subtitles(), min_size=1))
-def test_parse_file_with_missing_index(input_subs):  # cf. issue #51
-    for sub in input_subs:
-        try:
-            int(sub.content.strip().split("\n")[-1])
-        except ValueError:
-            pass
-        else:
-            # If the final line with actual content is a number, we'll parse it
-            # as the index, so ignore that
-            assume(False)
-
-    out_no_index = ""
-    out_zero_index = ""
-
-    for sub in input_subs:
-        block = sub.to_srt()
-        block = block[block.index("\n") + 1 :]
-        out_no_index += block
-
-    input_subs_copy = [srt.Subtitle(**vars(sub)) for sub in input_subs]
-    for sub in input_subs_copy:
-        # sub.index == None will get rendered in to_srt as 0
-        sub.index = 0
-        out_zero_index += sub.to_srt()
-
-    subs_no_index = list(srt.parse(out_no_index))
-    subs_zero_index = list(srt.parse(out_zero_index))
-
-    # One should have index == None, one should have index == 0...
-    assert subs_no_index
-    assert subs_zero_index
-    assert all(sub.index == None for sub in subs_no_index)
-    assert all(sub.index == 0 for sub in subs_zero_index)
-    assert subs_no_index != subs_zero_index
-
-    # ...but they should render the same...
-    assert srt.compose(subs_no_index, reindex=False) == srt.compose(
-        subs_zero_index, reindex=False
-    )
-
-    # ...and sort the same.
-    assert srt.compose(subs_no_index) == srt.compose(subs_zero_index)
